@@ -23,16 +23,8 @@ class Db:
     class, that knowns about internals of Mongodb.
     '''
 
-    def __init__(self, host: str, port: int, name: str, username:str|None=None, password:str|None=None) -> None:
-        kwargs = {}
-        if username is not None:
-            kwargs['username'] = username
-            kwargs['password'] = password
-        self.client = MongoClient(
-            host, 
-            port,
-            **kwargs
-        )
+    def __init__(self, host: str, port: int, name: str) -> None:
+        self.client = MongoClient(host, port)
         self.name = name
         self.db = self.client[name]
 
@@ -55,17 +47,20 @@ class Db:
         roll back your change where you added a field to you protobuf-message definition.
         In this way, no data is lost.
         '''
+        original = message
+        if hasattr(original, 'proto'):
+            message = message.proto
 
-        # TODO: check if it is already a proto-message,
-        #       or wether it is a wrapped one
         table = self.db[message.DESCRIPTOR.full_name]
         doc = MessageToDict(message)
         if not doc.get('id'):
             doc['id'] = str(uuid.uuid4())
 
         updating = bool(table.find_one({'_id': doc['id']}))
-        if hasattr(message, 'set_defaults'):
-            message.set_defaults(creating=not updating)
+        if hasattr(original, 'set_defaults'):
+            original.set_defaults(creating=not updating)
+            if hasattr(original, 'proto'):
+                message = original.proto
 
         doc2 = MessageToDict(message)
         doc2['id'] = doc['id']
@@ -86,7 +81,10 @@ class Db:
         # in the database-doc than in the message. This happens when we
         # store metadata, like _id or deleted a field (we don't want to
         # loose this data)
-        return ParseDict(doc, message, ignore_unknown_fields=True)
+        proto = ParseDict(doc, message, ignore_unknown_fields=True)
+        if hasattr(original, 'proto'):
+            original.proto = proto
+        return original
 
     def get(self, messageClass: type, **kwargs):
         res = self.query(messageClass, query=kwargs)
