@@ -60,6 +60,19 @@ class ProtoMessage:
         res += '}'
         return res
 
+    @property
+    def is_entity(self) -> bool:
+        '''
+        Returns True if this message is an entity, i.e. it has a field
+        `id` of type `string` and `createdAt` and `lastUpdatedAt` of type
+        `int64`.
+        '''
+        for field in self.fields:
+            if field.tag == 1:
+                if field.name == 'id':
+                    return True
+        return False
+
 
 class ProtoField:
 
@@ -199,6 +212,15 @@ class AstToGrpcAst:
                     field.repeated))
         self.messages.append(protoMsg)
 
+        if protoMsg.is_entity:
+            refMessage = ProtoMessage(modelMessage.name + 'Ref')
+            refMessage.fields.append(ProtoField('string', 'id', 1))
+            refMessage.fields.append(ProtoField('bool', 'resolved', 2))
+            refMessage.fields.append(ProtoField(protoMsg.name, 'data', 3))
+            self.messages.append(
+                refMessage
+            )
+
         # 2. create all required messages for the rpc-methods
         for method in modelMessage.rpc_methods:
 
