@@ -97,9 +97,10 @@ class Message:
             if isinstance(field, ReferenceField):
                 if field.repeated:
                     referenceIdFields[field.name] = [
-                        o.id for o in kwargs[name]]
+                        {'id': o.id} for o in kwargs[name]]
                 else:
-                    referenceIdFields[field.name] = kwargs[name].id
+                    referenceIdFields[field.name] = {'id': kwargs[name].id}
+
         # because referenceIdFields come second, they override
         kwargs = {**kwargs, **referenceIdFields}
 
@@ -157,6 +158,7 @@ class Message:
             #   - the requested attribute is id, as is is has to be already present, thus no need for lazy loading
             #   - we not already have done so. The DB- and Web-Layer set _loaded to false when creating an instance
             #   - the ID is not set, lazy loading converts the ID to the data
+
             if not name == 'id' and not attr('_loaded') and attr('id'):
                 db_result = self.db.query(
                     attr('proto').__class__, {
@@ -173,7 +175,42 @@ class Message:
 
             # lazy loading not required / has no effect. Return the value already in the proto-message
             # This should be the normal case
-            return getattr(proto, name)
+            res = getattr(proto, name)
+            return res
+
+        def resolve_repeated_reference_field(value):
+            attribute_value = attr(name)
+
+            foreign_objects_ids = list(
+                e.id for e in getattr(
+                    attr('proto'),
+                    attribute_value.name))
+            db_res = self.db.query(
+                attribute_value.other, {
+                    '_id': {
+                        '$in': foreign_objects_ids}})
+            if not db_res:
+                return []
+
+            # setattr(self, name, db_res)
+            return db_res
+
+        def resolve_reference_field(value):
+            attribute_value = attr(name)
+
+            foreign_object_id = getattr(value, 'id')
+            if not foreign_object_id:
+                return value
+
+            db_res = self.db.query(
+                attribute_value.other, {
+                    '_id': foreign_object_id})
+            if not db_res:
+                return None  # Or create an empty instance ??
+
+            value = db_res[0]
+
+            return value
 
         # normal case, if values are present and lazy-loading
         #  ===================================================
@@ -181,7 +218,17 @@ class Message:
         # directoly or load it on the fly
         proto = attr('proto')
         if hasattr(proto, name):
-            return take_value_from_proto_and_maybe_lazy_load()
+            res = take_value_from_proto_and_maybe_lazy_load()
+
+            if res.__class__.__name__ == 'RepeatedCompositeContainer':
+                attribute_value = attr(name)
+                if attribute_value.protoType.endswith('Ref'):
+                    return resolve_repeated_reference_field(res)
+
+            if res.__class__.__name__.endswith('Ref'):
+                return resolve_reference_field(res)
+
+            return res
 
         # ReferenceFields (Foreign Keys) Lazy Loading
         #  ==============================================
@@ -456,27 +503,15 @@ class ReferenceField(Field):
     def __init__(self, tag, other, repeated=False):
         if isinstance(other, Late):
             other = other()  # for cyclic refs, wrap in lambda
+
+        name = other.__name__ if hasattr(
+            other, '__name__') else str(other)
+        name = name + 'Ref'
+
         self.other = other
-        self.protoType = 'string'  # IDs are always strings, and we only store IDs
+        self.protoType = name
         super().__init__(tag, repeated=repeated)
 
-    @property
-    def name(self) -> str:
-        if self._name is None:
-            return self._name
-        suffix = 'Id'
-        if self.repeated:
-            suffix = 'Ids'
-        return self._name + suffix
-
-    @name.setter
-    def name(self, name: str) -> None:
-        self._name = name
-
-    @property
-    def otherClass(self) -> type:
-        return self.other
-
 
 _rpc_methods = {}
 
